==> gauche_0.9.5.orig.tar.gz: Gauche-0.9.5/src/libsrfis.scm <==
(inline-stub (initcode
(Scm_AddFeature "srfi-0" NULL)
(Scm_AddFeature "srfi-1" "srfi-1")
(Scm_AddFeature "srfi-2" NULL)
(Scm_AddFeature "srfi-4" "gauche.uvector")
(Scm_AddFeature "srfi-5" "srfi-5")
(Scm_AddFeature "srfi-6" NULL)
(Scm_AddFeature "srfi-7" NULL)
(Scm_AddFeature "srfi-8" NULL)
(Scm_AddFeature "srfi-9" "gauche.record")
(Scm_AddFeature "srfi-10" NULL)
(Scm_AddFeature "srfi-11" "srfi-11")
(Scm_AddFeature "srfi-13" "srfi-13")
(Scm_AddFeature "srfi-14" "srfi-14")
(Scm_AddFeature "srfi-16" NULL)
(Scm_AddFeature "srfi-17" NULL)
(Scm_AddFeature "srfi-18" "gauche.threads")
(Scm_AddFeature "srfi-19" "srfi-19")
(Scm_AddFeature "srfi-22" NULL)
(Scm_AddFeature "srfi-23" NULL)
(Scm_AddFeature "srfi-25" "gauche.array")
(Scm_AddFeature "srfi-26" "srfi-26")
(Scm_AddFeature "srfi-27" "srfi-27")
(Scm_AddFeature "srfi-28" NULL)
(Scm_AddFeature "srfi-29" "srfi-29")
(Scm_AddFeature "srfi-30" NULL)
(Scm_AddFeature "srfi-31" NULL)
(Scm_AddFeature "srfi-34" NULL)
(Scm_AddFeature "srfi-35" NULL)
(Scm_AddFeature "srfi-36" NULL)
(Scm_AddFeature "srfi-37" "srfi-37")
(Scm_AddFeature "srfi-38" NULL)
(Scm_AddFeature "srfi-39" "gauche.parameter")
(Scm_AddFeature "srfi-40" "util.stream")
(Scm_AddFeature "srfi-42" "srfi-42")
(Scm_AddFeature "srfi-43" "srfi-43")
(Scm_AddFeature "srfi-45" NULL)
(Scm_AddFeature "srfi-46" NULL)
(Scm_AddFeature "srfi-55" "srfi-55")
(Scm_AddFeature "srfi-60" "srfi-60")
(Scm_AddFeature "srfi-61" NULL)
(Scm_AddFeature "srfi-62" NULL)
(Scm_AddFeature "srfi-69" NULL)
(Scm_AddFeature "srfi-78" NULL)
(Scm_AddFeature "srfi-87" NULL)
(Scm_AddFeature "srfi-95" NULL)
(Scm_AddFeature "srfi-98" "srfi-98")
(Scm_AddFeature "srfi-99" "gauche.record")
(Scm_AddFeature "srfi-106" "srfi-106")
(Scm_AddFeature "srfi-111" "srfi-111")
(Scm_AddFeature "srfi-112" "srfi-112")
(Scm_AddFeature "srfi-113" "srfi-113")
(Scm_AddFeature "srfi-114" "srfi-114")
(Scm_AddFeature "srfi-117" "srfi-117")
(Scm_AddFeature "srfi-118" "srfi-118")
(Scm_AddFeature "srfi-121" "gauche.generator")
(Scm_AddFeature "srfi-128" NULL)
(Scm_AddFeature "srfi-131" "gauche.record")
(Scm_AddFeature "srfi-133" NULL)
(Scm_AddFeature "srfi-134" NULL)
))
(define-module srfi-2 (export and-let*))
(define-module srfi-6 (export open-input-string open-output-string get-output-string))
(define-module srfi-8 (export receive))
(define-module srfi-10 (export define-reader-ctor))
(define-module srfi-16 (export case-lambda))
(define-module srfi-17 (export setter getter-with-setter))
(define-module srfi-23 (export error))
(define-module srfi-28 (export format))
(define-module srfi-34 (export with-exception-handler guard raise))
(define-module srfi-35 (export make-condition-type condition-type? make-condition condition? condition-has-type? condition-ref make-compound-condition extract-condition define-condition-type condition &condition &message &serious &error))
(define-module srfi-36 (export &i/o-error &i/o-port-error &i/o-read-error &i/o-write-error &i/o-closed-error &read-error))
(define-module srfi-38 (export write-with-shared-structure write/ss read-with-shared-structure read/ss))
(define-module srfi-45 (export delay force lazy eager))
(define-module srfi-46 (export syntax-rules |...|))
(define-module srfi-61 (export cond else))
(define-module srfi-87 (export case => else))
(define-module srfi-95 (export sorted? merge merge! sort sort!))
(define-module srfi-111 (export box box? unbox set-box!))

==> gauche_0.9.6.orig.tar.gz: Gauche-0.9.6/src/libsrfis.scm <==
(inline-stub (initcode
(Scm_AddFeature "srfi-0" NULL)
(Scm_AddFeature "srfi-1" "srfi-1")
(Scm_AddFeature "srfi-2" NULL)
(Scm_AddFeature "srfi-4" "gauche.uvector")
(Scm_AddFeature "srfi-5" "srfi-5")
(Scm_AddFeature "srfi-6" NULL)
(Scm_AddFeature "srfi-7" NULL)
(Scm_AddFeature "srfi-8" NULL)
(Scm_AddFeature "srfi-9" "gauche.record")
(Scm_AddFeature "srfi-10" NULL)
(Scm_AddFeature "srfi-11" NULL)
(Scm_AddFeature "srfi-13" "srfi-13")
(Scm_AddFeature "srfi-14" "srfi-14")
(Scm_AddFeature "srfi-16" NULL)
(Scm_AddFeature "srfi-17" NULL)
(Scm_AddFeature "srfi-18" "gauche.threads")
(Scm_AddFeature "srfi-19" "srfi-19")
(Scm_AddFeature "srfi-22" NULL)
(Scm_AddFeature "srfi-23" NULL)
(Scm_AddFeature "srfi-25" "gauche.array")
(Scm_AddFeature "srfi-26" "srfi-26")
(Scm_AddFeature "srfi-27" "srfi-27")
(Scm_AddFeature "srfi-28" NULL)
(Scm_AddFeature "srfi-29" "srfi-29")
(Scm_AddFeature "srfi-30" NULL)
(Scm_AddFeature "srfi-31" "srfi-31")
(Scm_AddFeature "srfi-34" NULL)
(Scm_AddFeature "srfi-35" NULL)
(Scm_AddFeature "srfi-36" NULL)
(Scm_AddFeature "srfi-37" "srfi-37")
(Scm_AddFeature "srfi-38" NULL)
(Scm_AddFeature "srfi-39" "gauche.parameter")
(Scm_AddFeature "srfi-40" "util.stream")
(Scm_AddFeature "srfi-42" "srfi-42")
(Scm_AddFeature "srfi-43" "srfi-43")
(Scm_AddFeature "srfi-45" NULL)
(Scm_AddFeature "srfi-46" NULL)
(Scm_AddFeature "srfi-55" "srfi-55")
(Scm_AddFeature "srfi-60" "srfi-60")
(Scm_AddFeature "srfi-61" NULL)
(Scm_AddFeature "srfi-62" NULL)
(Scm_AddFeature "srfi-64" "srfi-64")
(Scm_AddFeature "srfi-66" "srfi-66")
(Scm_AddFeature "srfi-69" "srfi-69")
(Scm_AddFeature "srfi-74" "srfi-74")
(Scm_AddFeature "srfi-78" "srfi-78")
(Scm_AddFeature "srfi-87" NULL)
(Scm_AddFeature "srfi-95" NULL)
(Scm_AddFeature "srfi-96" "srfi-96")
(Scm_AddFeature "srfi-98" "srfi-98")
(Scm_AddFeature "srfi-99" "gauche.record")
(Scm_AddFeature "srfi-106" "srfi-106")
(Scm_AddFeature "srfi-111" "srfi-111")
(Scm_AddFeature "srfi-112" "srfi-112")
(Scm_AddFeature "srfi-113" "srfi-113")
(Scm_AddFeature "srfi-114" "srfi-114")
(Scm_AddFeature "srfi-117" "srfi-117")
(Scm_AddFeature "srfi-118" "srfi-118")
(Scm_AddFeature "srfi-121" "gauche.generator")
(Scm_AddFeature "srfi-125" "srfi-125")
(Scm_AddFeature "srfi-127" "srfi-127")
(Scm_AddFeature "srfi-128" "srfi-128")
(Scm_AddFeature "srfi-129" "srfi-129")
(Scm_AddFeature "srfi-131" "gauche.record")
(Scm_AddFeature "srfi-132" "srfi-132")
(Scm_AddFeature "srfi-133" "srfi-133")
(Scm_AddFeature "srfi-134" "data.ideque")
(Scm_AddFeature "srfi-141" "srfi-141")
(Scm_AddFeature "srfi-143" "srfi-143")
(Scm_AddFeature "srfi-145" NULL)
(Scm_AddFeature "srfi-146" NULL)
(Scm_AddFeature "srfi-149" NULL)
(Scm_AddFeature "srfi-151" "srfi-151")
(Scm_AddFeature "srfi-152" "srfi-152")
(Scm_AddFeature "srfi-158" "srfi-158")
))
(define-module srfi-2 (export and-let*))
(define-module srfi-6 (export open-input-string open-output-string get-output-string))
(define-module srfi-8 (export receive))
(define-module srfi-10 (export define-reader-ctor))
(define-module srfi-11 (export let-values let*-values))
(define-module srfi-16 (export case-lambda))
(define-module srfi-17 (export setter getter-with-setter))
(define-module srfi-23 (export error))
(define-module srfi-28 (export format))
(define-module srfi-34 (export with-exception-handler guard raise))
(define-module srfi-35 (export make-condition-type condition-type? make-condition condition? condition-has-type? condition-ref make-compound-condition extract-condition define-condition-type condition &condition &message &serious &error))
(define-module srfi-36 (export &i/o-error &i/o-port-error &i/o-read-error &i/o-write-error &i/o-closed-error &read-error))
(define-module srfi-38 (export write-with-shared-structure write/ss read-with-shared-structure read/ss))
(define-module srfi-45 (export delay force lazy eager))
(define-module srfi-46 (export syntax-rules ...))
(define-module srfi-61 (export cond else))
(define-module srfi-87 (export case => else))
(define-module srfi-95 (export sorted? merge merge! sort sort!))
(define-module srfi-111 (export box box? unbox set-box!))
(define-module srfi-145 (export assume))
(define-module srfi-149 (export syntax-rules))
